@@ -46,8 +46,28 @@ class PointIdent(enum.Enum):
 class ClientSettings:
 
     def __init__(self):
-        self.renew_time = 5 * 60
-        self.query_expire_time = None
+        self._renew_time = 5 * 60
+        self._query_expire_time = None
+
+    @property
+    def query_expire_time(self):
+        """The timeout for a query in seconds. If this time expires
+        then the blockchain method will return libbitcoin.ErrorCode
+        Set to None for no timeout."""
+        return self._query_expire_time
+    @query_expire_time.setter
+    def query_expire_time(self, query_expire_time):
+        self._query_expire_time = query_expire_time
+
+    @property
+    def renew_time(self):
+        """The renew time for address or stealth subscriptions.
+        This number should be lower than the setting for the blockchain
+        server. A good value is server_renew_time / 2"""
+        return self._renew_time
+    @renew_time.setter
+    def renew_time(self, renew_time):
+        self._renew_time = renew_time
 
 class Client:
 
@@ -74,6 +94,8 @@ class Client:
         await self._socket.send_multipart(request)
 
     async def request(self, request_command, request_data):
+        """Make a generic request. Both options are byte objects specified like
+        b"blockchain.fetch_block_header" as an example."""
         future = self._context.Future()
         request_id = create_random_id()
         self._context.poller.add_future(request_id, future)
@@ -184,7 +206,7 @@ class Client:
 
     async def transaction_index(self, tx_hash):
         """Fetch the block height that contains a transaction and its index
-        within a block."""
+        within that block."""
         command = b"blockchain.fetch_transaction_index"
         data = libbitcoin.serialize.serialize_hash(tx_hash)
         ec, data = await self.request(command, data)
@@ -245,7 +267,7 @@ class Client:
         return ec, rows
 
     async def total_connections(self):
-        """Fetches the total number of connections."""
+        """Fetches the total number of server connections."""
         command = b"protocol.total_connections"
         ec, data = await self.request(command, b"")
         if ec:
